/*
 * Copyright 2011, Blender Foundation.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef CCL_API_H
#define CCL_API_H

#ifdef __cplusplus
extern "C" {
#endif

/* returns a list of devices for selection, array is empty identifier
 * terminated and must not be freed */

typedef struct CCLDeviceInfo {
	char identifier[128];
	char name[512];
	int value;
} CCLDeviceInfo;

CCLDeviceInfo *CCL_compute_device_list(int opencl);

/* create python module _cycles used by addon */

void *CCL_python_module_init(void);

#ifdef __cplusplus
}
#endif

#endif /* CCL_API_H */

